@@ -3,7 +3,7 @@ package ColorTheme::Test::Dynamic;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-19'; # DATE
 our $DIST = 'ColorThemeBase-Static'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use strict;
 use warnings;
@@ -18,6 +18,12 @@ our %THEME = (
         opt1 => {schema=>'str*', default=>'foo'},
         opt2 => {schema=>'str*'},
     },
+    examples => [
+        {
+            summary => 'An red tone',
+            args => { tone => 'red' },
+        },
+    ],
 );
 
 sub list_items {
@@ -60,7 +66,7 @@ ColorTheme::Test::Dynamic - A dynamic color theme
 
 =head1 VERSION
 
-This document describes version 0.007 of ColorTheme::Test::Dynamic (from Perl distribution ColorThemeBase-Static), released on 2020-06-19.
+This document describes version 0.008 of ColorTheme::Test::Dynamic (from Perl distribution ColorThemeBase-Static), released on 2020-06-19.
 
 =head1 HOMEPAGE
 
